@@ -7,6 +7,7 @@
 package fs
 
 import (
+	"errors"
 	"time"
 )
 
@@ -17,41 +18,38 @@ type database interface {
 	Delete(key string) error
 }
 
-// The MtimeFS is a filesystem with nanosecond mtime precision, regardless
-// of what shenanigans the underlying filesystem gets up to. A nil MtimeFS
-// just does the underlying operations with no additions.
-type MtimeFS struct {
+type mtimeFS struct {
 	Filesystem
 	chtimes         func(string, time.Time, time.Time) error
 	db              database
 	caseInsensitive bool
 }
 
-type MtimeFSOption func(*MtimeFS)
+type MtimeFSOption func(*mtimeFS)
 
 func WithCaseInsensitivity(v bool) MtimeFSOption {
-	return func(f *MtimeFS) {
+	return func(f *mtimeFS) {
 		f.caseInsensitive = v
 	}
 }
 
-func NewMtimeFS(underlying Filesystem, db database, options ...MtimeFSOption) *MtimeFS {
-	f := &MtimeFS{
-		Filesystem: underlying,
-		chtimes:    underlying.Chtimes, // for mocking it out in the tests
-		db:         db,
-	}
-	for _, opt := range options {
-		opt(f)
-	}
-	return f
+// NewMtimeFS returns a filesystem with nanosecond mtime precision, regardless
+// of what shenanigans the underlying filesystem gets up to.
+func NewMtimeFS(fs Filesystem, db database, options ...MtimeFSOption) Filesystem {
+	return wrapFilesystem(fs, func(underlying Filesystem) Filesystem {
+		f := &mtimeFS{
+			Filesystem: underlying,
+			chtimes:    underlying.Chtimes, // for mocking it out in the tests
+			db:         db,
+		}
+		for _, opt := range options {
+			opt(f)
+		}
+		return f
+	})
 }
 
-func (f *MtimeFS) Chtimes(name string, atime, mtime time.Time) error {
-	if f == nil {
-		return f.chtimes(name, atime, mtime)
-	}
-
+func (f *mtimeFS) Chtimes(name string, atime, mtime time.Time) error {
 	// Do a normal Chtimes call, don't care if it succeeds or not.
 	f.chtimes(name, atime, mtime)
 
@@ -66,58 +64,58 @@ func (f *MtimeFS) Chtimes(name string, atime, mtime time.Time) error {
 	return nil
 }
 
-func (f *MtimeFS) Stat(name string) (FileInfo, error) {
+func (f *mtimeFS) Stat(name string) (FileInfo, error) {
 	info, err := f.Filesystem.Stat(name)
 	if err != nil {
 		return nil, err
 	}
 
-	real, virtual, err := f.load(name)
+	mtimeMapping, err := f.load(name)
 	if err != nil {
 		return nil, err
 	}
-	if real == info.ModTime() {
+	if mtimeMapping.Real == info.ModTime() {
 		info = mtimeFileInfo{
 			FileInfo: info,
-			mtime:    virtual,
+			mtime:    mtimeMapping.Virtual,
 		}
 	}
 
 	return info, nil
 }
 
-func (f *MtimeFS) Lstat(name string) (FileInfo, error) {
+func (f *mtimeFS) Lstat(name string) (FileInfo, error) {
 	info, err := f.Filesystem.Lstat(name)
 	if err != nil {
 		return nil, err
 	}
 
-	real, virtual, err := f.load(name)
+	mtimeMapping, err := f.load(name)
 	if err != nil {
 		return nil, err
 	}
-	if real == info.ModTime() {
+	if mtimeMapping.Real == info.ModTime() {
 		info = mtimeFileInfo{
 			FileInfo: info,
-			mtime:    virtual,
+			mtime:    mtimeMapping.Virtual,
 		}
 	}
 
 	return info, nil
 }
 
-func (f *MtimeFS) Walk(root string, walkFn WalkFunc) error {
+func (f *mtimeFS) Walk(root string, walkFn WalkFunc) error {
 	return f.Filesystem.Walk(root, func(path string, info FileInfo, err error) error {
 		if info != nil {
-			real, virtual, loadErr := f.load(path)
+			mtimeMapping, loadErr := f.load(path)
 			if loadErr != nil && err == nil {
 				// The iterator gets to deal with the error
 				err = loadErr
 			}
-			if real == info.ModTime() {
+			if mtimeMapping.Real == info.ModTime() {
 				info = mtimeFileInfo{
 					FileInfo: info,
-					mtime:    virtual,
+					mtime:    mtimeMapping.Virtual,
 				}
 			}
 		}
@@ -125,7 +123,7 @@ func (f *MtimeFS) Walk(root string, walkFn WalkFunc) error {
 	})
 }
 
-func (f *MtimeFS) Create(name string) (File, error) {
+func (f *mtimeFS) Create(name string) (File, error) {
 	fd, err := f.Filesystem.Create(name)
 	if err != nil {
 		return nil, err
@@ -133,7 +131,7 @@ func (f *MtimeFS) Create(name string) (File, error) {
 	return mtimeFile{fd, f}, nil
 }
 
-func (f *MtimeFS) Open(name string) (File, error) {
+func (f *mtimeFS) Open(name string) (File, error) {
 	fd, err := f.Filesystem.Open(name)
 	if err != nil {
 		return nil, err
@@ -141,7 +139,7 @@ func (f *MtimeFS) Open(name string) (File, error) {
 	return mtimeFile{fd, f}, nil
 }
 
-func (f *MtimeFS) OpenFile(name string, flags int, mode FileMode) (File, error) {
+func (f *mtimeFS) OpenFile(name string, flags int, mode FileMode) (File, error) {
 	fd, err := f.Filesystem.OpenFile(name, flags, mode)
 	if err != nil {
 		return nil, err
@@ -149,12 +147,17 @@ func (f *MtimeFS) OpenFile(name string, flags int, mode FileMode) (File, error)
 	return mtimeFile{fd, f}, nil
 }
 
-// "real" is the on disk timestamp
-// "virtual" is what want the timestamp to be
+func (f *mtimeFS) underlying() (Filesystem, bool) {
+	return f.Filesystem, true
+}
 
-func (f *MtimeFS) save(name string, real, virtual time.Time) {
+func (f *mtimeFS) wrapperType() filesystemWrapperType {
+	return filesystemWrapperTypeMtime
+}
+
+func (f *mtimeFS) save(name string, real, virtual time.Time) {
 	if f.caseInsensitive {
-		name = UnicodeLowercase(name)
+		name = UnicodeLowercaseNormalized(name)
 	}
 
 	if real.Equal(virtual) {
@@ -164,32 +167,31 @@ func (f *MtimeFS) save(name string, real, virtual time.Time) {
 		return
 	}
 
-	mtime := dbMtime{
-		real:    real,
-		virtual: virtual,
+	mtime := MtimeMapping{
+		Real:    real,
+		Virtual: virtual,
 	}
 	bs, _ := mtime.Marshal() // Can't fail
 	f.db.PutBytes(name, bs)
 }
 
-func (f *MtimeFS) load(name string) (real, virtual time.Time, err error) {
+func (f *mtimeFS) load(name string) (MtimeMapping, error) {
 	if f.caseInsensitive {
-		name = UnicodeLowercase(name)
+		name = UnicodeLowercaseNormalized(name)
 	}
 
 	data, exists, err := f.db.Bytes(name)
 	if err != nil {
-		return time.Time{}, time.Time{}, err
+		return MtimeMapping{}, err
 	} else if !exists {
-		return time.Time{}, time.Time{}, nil
+		return MtimeMapping{}, nil
 	}
 
-	var mtime dbMtime
+	var mtime MtimeMapping
 	if err := mtime.Unmarshal(data); err != nil {
-		return time.Time{}, time.Time{}, err
+		return MtimeMapping{}, err
 	}
-
-	return mtime.real, mtime.virtual, nil
+	return mtime, nil
 }
 
 // The mtimeFileInfo is an os.FileInfo that lies about the ModTime().
@@ -205,7 +207,7 @@ func (m mtimeFileInfo) ModTime() time.Time {
 
 type mtimeFile struct {
 	File
-	fs *MtimeFS
+	fs *mtimeFS
 }
 
 func (f mtimeFile) Stat() (FileInfo, error) {
@@ -214,43 +216,57 @@ func (f mtimeFile) Stat() (FileInfo, error) {
 		return nil, err
 	}
 
-	real, virtual, err := f.fs.load(f.Name())
+	mtimeMapping, err := f.fs.load(f.Name())
 	if err != nil {
 		return nil, err
 	}
-	if real == info.ModTime() {
+	if mtimeMapping.Real == info.ModTime() {
 		info = mtimeFileInfo{
 			FileInfo: info,
-			mtime:    virtual,
+			mtime:    mtimeMapping.Virtual,
 		}
 	}
 
 	return info, nil
 }
 
+// Used by copyRange to unwrap to the real file and access SyscallConn
 func (f mtimeFile) unwrap() File {
 	return f.File
 }
 
-// The dbMtime is our database representation
-
-type dbMtime struct {
-	real    time.Time
-	virtual time.Time
+// MtimeMapping represents the mapping as stored in the database
+type MtimeMapping struct {
+	// "Real" is the on disk timestamp
+	Real time.Time `json:"real"`
+	// "Virtual" is what want the timestamp to be
+	Virtual time.Time `json:"virtual"`
 }
 
-func (t *dbMtime) Marshal() ([]byte, error) {
-	bs0, _ := t.real.MarshalBinary()
-	bs1, _ := t.virtual.MarshalBinary()
+func (t *MtimeMapping) Marshal() ([]byte, error) {
+	bs0, _ := t.Real.MarshalBinary()
+	bs1, _ := t.Virtual.MarshalBinary()
 	return append(bs0, bs1...), nil
 }
 
-func (t *dbMtime) Unmarshal(bs []byte) error {
-	if err := t.real.UnmarshalBinary(bs[:len(bs)/2]); err != nil {
+func (t *MtimeMapping) Unmarshal(bs []byte) error {
+	if err := t.Real.UnmarshalBinary(bs[:len(bs)/2]); err != nil {
 		return err
 	}
-	if err := t.virtual.UnmarshalBinary(bs[len(bs)/2:]); err != nil {
+	if err := t.Virtual.UnmarshalBinary(bs[len(bs)/2:]); err != nil {
 		return err
 	}
 	return nil
 }
+
+func GetMtimeMapping(fs Filesystem, file string) (MtimeMapping, error) {
+	fs, ok := unwrapFilesystem(fs, filesystemWrapperTypeMtime)
+	if !ok {
+		return MtimeMapping{}, errors.New("failed to unwrap")
+	}
+	mtimeFs, ok := fs.(*mtimeFS)
+	if !ok {
+		return MtimeMapping{}, errors.New("unwrapping failed")
+	}
+	return mtimeFs.load(file)
+}
