@@ -1,5 +1,6 @@
 // Copyright (C) 2014 The Protocol Authors.
 
+//go:build darwin
 // +build darwin
 
 package protocol
@@ -8,6 +9,8 @@ package protocol
 
 import "golang.org/x/text/unicode/norm"
 
+func makeNative(m Model) Model { return nativeModel{m} }
+
 type nativeModel struct {
 	Model
 }
