@@ -4,6 +4,7 @@
 // License, v. 2.0. If a copy of the MPL was not distributed with this file,
 // You can obtain one at https://mozilla.org/MPL/2.0/.
 
+//go:build !noupgrade
 // +build !noupgrade
 
 package upgrade
@@ -18,7 +19,6 @@ import (
 	"errors"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"net/http"
 	"os"
 	"path"
@@ -283,7 +283,7 @@ func readTarGz(archiveName, dir string, r io.Reader) (string, error) {
 }
 
 func readZip(archiveName, dir string, r io.Reader) (string, error) {
-	body, err := ioutil.ReadAll(r)
+	body, err := io.ReadAll(r)
 	if err != nil {
 		return "", err
 	}
@@ -356,7 +356,7 @@ func archiveFileVisitor(dir string, tempFile *string, signature *[]byte, archive
 
 	case "release.sig":
 		l.Debugf("found signature %s", archivePath)
-		*signature, err = ioutil.ReadAll(io.LimitReader(filedata, maxSignatureSize))
+		*signature, err = io.ReadAll(io.LimitReader(filedata, maxSignatureSize))
 		if err != nil {
 			return err
 		}
@@ -391,7 +391,7 @@ func verifyUpgrade(archiveName, tempName string, sig []byte) error {
 	// multireader. This ensures that it is not only a bonafide syncthing
 	// binary, but it is also of exactly the platform and version we expect.
 
-	mr := io.MultiReader(bytes.NewBufferString(archiveName+"\n"), fd)
+	mr := io.MultiReader(strings.NewReader(archiveName+"\n"), fd)
 	err = signature.Verify(SigningKey, sig, mr)
 	fd.Close()
 
@@ -406,7 +406,7 @@ func verifyUpgrade(archiveName, tempName string, sig []byte) error {
 func writeBinary(dir string, inFile io.Reader) (filename string, err error) {
 	// Write the binary to a temporary file.
 
-	outFile, err := ioutil.TempFile(dir, "syncthing")
+	outFile, err := os.CreateTemp(dir, "syncthing")
 	if err != nil {
 		return "", err
 	}
