@@ -4,6 +4,7 @@
 // License, v. 2.0. If a copy of the MPL was not distributed with this file,
 // You can obtain one at https://mozilla.org/MPL/2.0/.
 
+//go:build integration
 // +build integration
 
 package integration
@@ -12,7 +13,6 @@ import (
 	"bytes"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"log"
 	"os"
 	"path/filepath"
@@ -146,7 +146,7 @@ func createFiles(t *testing.T) int {
 	const n = 8
 	for i := 0; i < n; i++ {
 		file := fmt.Sprintf("f%d", i)
-		if err := ioutil.WriteFile(filepath.Join("s1", file), []byte("data"), 0644); err != nil {
+		if err := os.WriteFile(filepath.Join("s1", file), []byte("data"), 0644); err != nil {
 			t.Fatal(err)
 		}
 	}
